/* ia64_table.h --
 * Copyright 2005-14 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors:
 *      Steve Grubb <sgrubb@redhat.com>
 */

_S(1024, "ni_syscall")
_S(1025, "exit")
_S(1026, "read")
_S(1027, "write")
_S(1028, "open")
_S(1029, "close")
_S(1030, "creat")
_S(1031, "link")
_S(1032, "unlink")
_S(1033, "execve")
_S(1034, "chdir")
_S(1035, "fchdir")
_S(1036, "utimes")
_S(1037, "mknod")
_S(1038, "chmod")
_S(1039, "chown")
_S(1040, "lseek")
_S(1041, "getpid")
_S(1042, "getppid")
_S(1043, "mount")
_S(1044, "umount")
_S(1045, "setuid")
_S(1046, "getuid")
_S(1047, "geteuid")
_S(1048, "ptrace")
_S(1049, "access")
_S(1050, "sync")
_S(1051, "fsync")
_S(1052, "fdatasync")
_S(1053, "kill")
_S(1054, "rename")
_S(1055, "mkdir")
_S(1056, "rmdir")
_S(1057, "dup")
_S(1058, "pipe")
_S(1059, "times")
_S(1060, "brk")
_S(1061, "setgid")
_S(1062, "getgid")
_S(1063, "getegid")
_S(1064, "acct")
_S(1065, "ioctl")
_S(1066, "fcntl")
_S(1067, "umask")
_S(1068, "chroot")
_S(1069, "ustat")
_S(1070, "dup2")
_S(1071, "setreuid")
_S(1072, "setregid")
_S(1073, "getresuid")
_S(1074, "setresuid")
_S(1075, "getresgid")
_S(1076, "setresgid")
_S(1077, "getgroups")
_S(1078, "setgroups")
_S(1079, "getpgid")
_S(1080, "setpgid")
_S(1081, "setsid")
_S(1082, "getsid")
_S(1083, "sethostname")
_S(1084, "setrlimit")
_S(1085, "getrlimit")
_S(1086, "getrusage")
_S(1087, "gettimeofday")
_S(1088, "settimeofday")
_S(1089, "select")
_S(1090, "poll")
_S(1091, "symlink")
_S(1092, "readlink")
_S(1093, "uselib")
_S(1094, "swapon")
_S(1095, "swapoff")
_S(1096, "reboot")
_S(1097, "truncate")
_S(1098, "ftruncate")
_S(1099, "fchmod")
_S(1100, "fchown")
_S(1101, "getpriority")
_S(1102, "setpriority")
_S(1103, "statfs")
_S(1104, "fstatfs")
_S(1105, "gettid")
_S(1106, "semget")
_S(1107, "semop")
_S(1108, "semctl")
_S(1109, "msgget")
_S(1110, "msgsnd")
_S(1111, "msgrcv")
_S(1112, "msgctl")
_S(1113, "shmget")
_S(1114, "shmat")
_S(1115, "shmdt")
_S(1116, "shmctl")
_S(1117, "syslog")
_S(1118, "setitimer")
_S(1119, "getitimer")
_S(1120, "tux")
_S(1123, "vhangup")
_S(1124, "lchown")
_S(1125, "remap_file_pages")
_S(1126, "wait4")
_S(1127, "sysinfo")
_S(1128, "clone")
_S(1129, "setdomainname")
_S(1130, "uname")
_S(1131, "adjtimex")
_S(1133, "init_module")
_S(1134, "delete_module")
_S(1137, "quotactl")
_S(1138, "bdflush")
_S(1139, "sysfs")
_S(1140, "personality")
_S(1141, "afs_syscall")
_S(1142, "setfsuid")
_S(1143, "setfsgid")
_S(1144, "getdents")
_S(1145, "flock")
_S(1146, "readv")
_S(1147, "writev")
_S(1148, "pread64")
_S(1149, "pwrite64")
_S(1150, "_sysctl")
_S(1151, "mmap")
_S(1152, "munmap")
_S(1153, "mlock")
_S(1154, "mlockall")
_S(1155, "mprotect")
_S(1156, "mremap")
_S(1157, "msync")
_S(1158, "munlock")
_S(1159, "munlockall")
_S(1160, "sched_getparam")
_S(1161, "sched_setparam")
_S(1162, "sched_getscheduler")
_S(1163, "sched_setscheduler")
_S(1164, "sched_yield")
_S(1165, "sched_get_priority_max")
_S(1166, "sched_get_priority_min")
_S(1167, "sched_rr_get_interval")
_S(1168, "nanosleep")
_S(1169, "nfsservctl")
_S(1170, "prctl")
_S(1172, "mmap2")
_S(1173, "pciconfig_read")
_S(1174, "pciconfig_write")
_S(1175, "perfmonctl")
_S(1176, "sigaltstack")
_S(1177, "rt_sigaction")
_S(1178, "rt_sigpending")
_S(1179, "rt_sigprocmask")
_S(1180, "rt_sigqueueinfo")
_S(1181, "rt_sigreturn")
_S(1182, "rt_sigsuspend")
_S(1183, "rt_sigtimedwait")
_S(1184, "getcwd")
_S(1185, "capget")
_S(1186, "capset")
_S(1187, "sendfile")
_S(1188, "getpmsg")
_S(1189, "putpmsg")
_S(1190, "socket")
_S(1191, "bind")
_S(1192, "connect")
_S(1193, "listen")
_S(1194, "accept")
_S(1195, "getsockname")
_S(1196, "getpeername")
_S(1197, "socketpair")
_S(1198, "send")
_S(1199, "sendto")
_S(1200, "recv")
_S(1201, "recvfrom")
_S(1202, "shutdown")
_S(1203, "setsockopt")
_S(1204, "getsockopt")
_S(1205, "sendmsg")
_S(1206, "recvmsg")
_S(1207, "pivot_root")
_S(1208, "mincore")
_S(1209, "madvise")
_S(1210, "stat")
_S(1211, "lstat")
_S(1212, "fstat")
_S(1213, "clone2")
_S(1214, "getdents64")
_S(1215, "getunwind")
_S(1216, "readahead")
_S(1217, "setxattr")
_S(1218, "lsetxattr")
_S(1219, "fsetxattr")
_S(1220, "getxattr")
_S(1221, "lgetxattr")
_S(1222, "fgetxattr")
_S(1223, "listxattr")
_S(1224, "llistxattr")
_S(1225, "flistxattr")
_S(1226, "removexattr")
_S(1227, "lremovexattr")
_S(1228, "fremovexattr")
_S(1229, "tkill")
_S(1230, "futex")
_S(1231, "sched_setaffinity")
_S(1232, "sched_getaffinity")
_S(1233, "set_tid_address")
_S(1234, "fadvise64")
_S(1235, "tgkill")
_S(1236, "exit_group")
_S(1237, "lookup_dcookie")
_S(1238, "io_setup")
_S(1239, "io_destroy")
_S(1240, "io_getevents")
_S(1241, "io_submit")
_S(1242, "io_cancel")
_S(1243, "epoll_create")
_S(1244, "epoll_ctl")
_S(1245, "epoll_wait")
_S(1246, "restart_syscall")
_S(1247, "semtimedop")
_S(1248, "timer_create")
_S(1249, "timer_settime")
_S(1250, "timer_gettime")
_S(1251, "timer_getoverrun")
_S(1252, "timer_delete")
_S(1253, "clock_settime")
_S(1254, "clock_gettime")
_S(1255, "clock_getres")
_S(1256, "clock_nanosleep")
_S(1257, "fstatfs64")
_S(1258, "statfs64")
_S(1259, "mbind")
_S(1260, "get_mempolicy")
_S(1261, "set_mempolicy")
_S(1262, "mq_open")
_S(1263, "mq_unlink")
_S(1264, "mq_timedsend")
_S(1265, "mq_timedreceive")
_S(1266, "mq_notify")
_S(1267, "mq_getsetattr")
_S(1268, "kexec_load")
_S(1269, "vserver")
_S(1270, "waitid")
_S(1271, "add_key")
_S(1272, "request_key")
_S(1273, "keyctl")
_S(1274, "ioprio_set")
_S(1275, "ioprio_get")
_S(1276, "set_zone_reclaim")
_S(1277, "inotify_init")
_S(1278, "inotify_add_watch")
_S(1279, "inotify_rm_watch")
_S(1280, "migrate_pages")
_S(1281, "openat")
_S(1282, "mkdirat")
_S(1283, "mknodat")
_S(1284, "fchownat")
_S(1285, "futimesat")
_S(1286, "newfstatat")
_S(1287, "unlinkat")
_S(1288, "renameat")
_S(1289, "linkat")
_S(1290, "symlinkat")
_S(1291, "readlinkat")
_S(1292, "fchmodat")
_S(1293, "faccessat")
_S(1294, "pselect")
_S(1295, "ppoll")
_S(1296, "unshare")
_S(1297, "splice")
_S(1298, "set_robust_list")
_S(1299, "get_robust_list")
_S(1300, "sync_file_range")
_S(1301, "tee")
_S(1302, "vmsplice")
_S(1303, "fallocate")
_S(1304, "getcpu")
_S(1305, "epoll_pwait")
_S(1306, "utimensat")
_S(1307, "signalfd")
_S(1308, "timerfd")
_S(1309, "eventfd")
_S(1310, "timerfd_create")
_S(1311, "timerfd_settime")
_S(1312, "timerfd_gettime")
_S(1313, "signalfd4")
_S(1314, "eventfd2")
_S(1315, "epoll_create1")
_S(1316, "dup3")
_S(1317, "pipe2")
_S(1318, "inotify_init1")
_S(1319, "preadv")
_S(1320, "pwritev")
_S(1321, "rt_tgsigqueueinfo")
_S(1322, "recvmmsg")
_S(1323, "fanotify_init")
_S(1324, "fanotify_mark")
_S(1325, "prlimit64")
_S(1326, "name_to_handle_at")
_S(1327, "open_by_handle_at")
_S(1328, "clock_adjtime")
_S(1329, "syncfs")
_S(1330, "setns")
_S(1331, "sendmmsg")
_S(1332, "process_vm_readv")
_S(1333, "process_vm_writev")
_S(1334, "accept4")
_S(1335, "finit_module")
_S(1336, "sched_setattr")
_S(1337, "sched_getattr")
_S(1338, "renameat2")
